@@ -4,11 +4,11 @@ import os
 
 from mopidy import config, ext
 
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 
 class MopifyExtension(ext.Extension):
     dist_name = 'Mopidy-Mopify'
-    ext_name = 'mopify_webclient'
+    ext_name = 'mopify'
     version = __version__
 
     def get_default_config(self):
